Command-Line Interface
=================================

You can also use Awpy in command-line form. This is useful for automating tasks or for quick one-off operations. To get started, you can view the example below, which closely mirrors the parse demo example in the documentation.

.. code-block:: bash

   awpy parse natus-vincere-vs-virtus-pro-m1-overpass.dem --player-props X,Y,Z --other-props is_bomb_planted --verbose